<?php
/**
 * Exit if accessed directly.
 *
 * @package bp-user-todo-list
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Bptodo_Hooks' ) ) {

	/**
	 * Class to add custom hooks for this plugin
	 *
	 * @since    1.0.0
	 * @author   Wbcom Designs
	 */
	class Bptodo_Hooks {

		/**
		 * Constructor.
		 *
		 * @since    1.0.0
		 * @access   public
		 * @author   Wbcom Designs
		 */
		public function __construct() {
			add_action( 'bptodo_todo_notification', array( $this, 'bptodo_manage_todo_due_date' ) );
			// add_action( 'bp_member_header_actions', array( $this, 'bptodo_add_todo_button_on_member_header' ) );.
			add_action( 'bp_setup_admin_bar', array( $this, 'bptodo_setup_admin_bar' ), 80 );
			add_filter( 'manage_bp-todo_posts_columns', array( $this, 'bptodo_due_date_column_heading' ), 10 );
			add_action( 'manage_bp-todo_posts_custom_column', array( $this, 'bptodo_due_date_column_content' ), 10, 2 );
			add_filter( 'bp_notifications_get_registered_components', array( $this, 'bptodo_due_date_notifications_component' ) );
			add_filter( 'bp_notifications_get_notifications_for_user', array( $this, 'bptodo_format_due_date_notifications' ), 10, 8 );
			add_filter( 'cron_schedules', array( $this, 'bptodo_notification_cron_schedule' ) );
			add_shortcode( 'bptodo_by_category', array( $this, 'bptodo_by_categpry_template' ) );
			if ( ! wp_next_scheduled( 'bptodo_todo_notification' ) ) {
				wp_schedule_event( time(), 'every_six_hours', 'bptodo_todo_notification' );
			}
		}

		/**
		 * Actions performed to send mails and notifications whose due date has arrived.
		 *
		 * @since    1.0.0
		 * @access   public
		 * @author   Wbcom Designs
		 */
		public function bptodo_manage_todo_due_date() {
			global $bptodo;
			$args       = array(
				'post_type'      => 'bp-todo',
				'post_status'    => 'publish',
				'posts_per_page' => -1,
				'order_by'       => 'name',
				'order'          => 'ASC',
			);
			$todo_items = get_posts( $args );
			if ( ! empty( $todo_items ) ) {
				foreach ( $todo_items as $key => $todo ) {
					$todo_status = get_post_meta( $todo->ID, 'todo_status', true );
					$diff_days   = '';
					if ( 'complete' !== $todo_status ) {
						$author_id = $todo->post_author;
						$curr_date = date_create( date( 'Y-m-d' ) );
						$due_date  = date_create( get_post_meta( $todo->ID, 'todo_due_date', true ) );
						$diff      = date_diff( $curr_date, $due_date );
						if ( is_object( $diff ) ) {
							$diff_days = $diff->format( '%R%a' );
						}
						/** Check if mail sending is allowed. */
						if ( ! empty( $bptodo->send_mail ) && 'yes' == $bptodo->send_mail ) {

							/** If today is the due date. */
							if ( 0 == $diff_days ) {
								/** If the mail is not sent already. */
								$due_date_mail_sent = get_post_meta( $todo->ID, 'todo_last_day_mail_sent', true );
								if ( 'no' == $due_date_mail_sent ) {
									$author       = get_userdata( $author_id );
									$author_email = $author->data->user_email;
									$subject      = esc_html__( 'BPTODO Task - WordPress', 'wb-todo' );
									/* Translators: Get a To do title name */
									$messsage = sprintf( esc_html__( 'Your task: %1$s is going to exipre today. Kindly finish it up! Thanks!', 'wb-todo' ), esc_html( $todo->post_title ) );
									$headers  = 'From:' . 'testing@gmail.com';
									wp_mail( $author_email, $subject, $messsage, $headers );
									update_post_meta( $todo->ID, 'todo_last_day_mail_sent', 'yes' );
								}
							}
						}

						/** Check if notification sending is allowed. */
						if ( ! empty( $bptodo->send_notification ) && 'yes' == $bptodo->send_notification ) {
							/** If today is the due date. */
							if ( 0 == $diff_days ) {
								/** If the mail is not sent already. */
								$due_date_notification_sent = get_post_meta( $todo->ID, 'todo_last_day_notification_sent', true );
								if ( 'no' == $due_date_notification_sent ) {
									/** Send notification for appectance. */
									bp_notifications_add_notification(
										array(
											'user_id' => $author_id,
											'item_id' => $todo->ID,
											'secondary_item_id' => get_current_user_id(),
											'component_name' => 'bptodo_due_date',
											'component_action' => 'bptodo_due_date_action',
											'date_notified' => bp_core_current_time(),
											'is_new'  => 1,
										)
									);
									update_post_meta( $todo->ID, 'todo_last_day_notification_sent', 'yes' );
								}
							}
						}
					}
				}
			}
		}

		/**
		 * Actions performed to add a todo button on member header.
		 *
		 * @since    1.0.0
		 * @access   public
		 * @author   Wbcom Designs
		 */
		/*
		public function bptodo_add_todo_button_on_member_header() {

			global $bptodo;

			// echo $bptodo->hide_button;
			if ( 'yes' != $bptodo->hide_button ) {
				return;
			}

			$profile_menu_label = $bptodo->profile_menu_label;
			$profile_menu_slug  = $bptodo->profile_menu_slug;
			if ( bp_displayed_user_id() === bp_loggedin_user_id() ) {
				$todo_add_url = bp_core_get_userlink( bp_displayed_user_id(), false, true ) . $profile_menu_slug . '/add';
				?>
				<div id="bptodo-add-todo-btn" class="generic-button">
					<a href="<?php echo esc_attr( $todo_add_url ); ?>" class="add-todo"><?php echo sprintf( esc_html__( 'Add %1$s', 'wb-todo' ), esc_html( $profile_menu_label ) ); ?></a>
				</div>
				<?php
			}
		}
		*/

		/**
		 * Contain admin nav item.
		 *
		 * @since    1.0.0
		 * @access   public
		 * @author   Wbcom Designs
		 * @param    array $wp_admin_nav contain admin nav item.
		 */
		public function bptodo_setup_admin_bar( $wp_admin_nav = array() ) {
			global $wp_admin_bar, $bptodo;
			$profile_menu_slug         = $bptodo->profile_menu_slug;
			$profile_menu_label_plural = $bptodo->profile_menu_label_plural;
			$my_todo_items             = $bptodo->my_todo_items;

			$base_url      = bp_loggedin_user_domain() . $profile_menu_slug;
			$todo_add_url  = $base_url . '/add';
			$todo_list_url = $base_url . '/list';
			if ( is_user_logged_in() ) {
				$wp_admin_bar->add_menu(
					array(
						'parent' => 'my-account-buddypress',
						'id'     => 'my-account-' . $profile_menu_slug,
						'title'  => $profile_menu_label_plural . ' <span class="count">' . $my_todo_items . '</span>',
						'href'   => trailingslashit( $todo_list_url ),
					)
				);

				/** Add add-new submenu. */
				$wp_admin_bar->add_menu(
					array(
						'parent' => 'my-account-' . $profile_menu_slug,
						'id'     => 'my-account-' . $profile_menu_slug . '-list',
						'title'  => esc_html__( 'List', 'wb-todo' ),
						'href'   => trailingslashit( $todo_list_url ),
					)
				);

				/** Add add-new submenu. */
				$wp_admin_bar->add_menu(
					array(
						'parent' => 'my-account-' . $profile_menu_slug,
						'id'     => 'my-account-' . $profile_menu_slug . '-add',
						'title'  => esc_html__( 'Add', 'wb-todo' ),
						'href'   => trailingslashit( $todo_add_url ),
					)
				);
			}
		}

		/**
		 * Contain default settings.
		 *
		 * @since    1.0.0
		 * @access   public
		 * @author   Wbcom Designs
		 * @param    array $defaults contain default settings.
		 */
		public function bptodo_due_date_column_heading( $defaults ) {
			$defaults['due_date'] = esc_html__( 'Due Date', 'wb-todo' );
			$defaults['status']   = esc_html__( 'Status', 'wb-todo' );
			$defaults['todo_id']  = esc_html__( 'ID', 'wb-todo' );
			return $defaults;
		}

		/**
		 * Contain default settings.
		 *
		 * @since    1.0.0
		 * @access   public
		 * @author   Wbcom Designs
		 * @param    array $column_name contain default settings.
		 * @param    int   $post_id contain post id.
		 */
		public function bptodo_due_date_column_content( $column_name, $post_id ) {
			$due_date_str      = '';
			$due_date_td_class = '';

			if ( 'due_date' === $column_name ) {
				$due_date = get_post_meta( $post_id, 'todo_due_date', true );
				echo esc_html( date( 'F jS, Y', strtotime( $due_date ) ) );
			}

			if ( 'status' === $column_name ) {
				$todo_status = get_post_meta( $post_id, 'todo_status', true );
				$curr_date   = date_create( date( 'Y-m-d' ) );
				$due_date    = date_create( get_post_meta( $post_id, 'todo_due_date', true ) );
				$diff        = date_diff( $curr_date, $due_date );
				$diff_days   = $diff->format( '%R%a' );
				if ( $diff_days < 0 ) {
					/* Translators: Display Expiry Days */
					$due_date_str = sprintf( esc_html__( 'Expired %d days ago!', 'wb-todo' ), abs( $diff_days ) );
				} elseif ( 0 === $diff_days ) {
					$due_date_str = esc_html__( 'Today is the last day to complete. Hurry Up!', 'wb-todo' );
				} else {
					/* Translators: Dislpay the left days  */
					$due_date_str = sprintf( esc_html__( '%d days left to complete the task!', 'wb-todo' ), abs( $diff_days ) );
				}

				if ( 'complete' === $todo_status ) {
					$due_date_str = esc_html__( 'Completed!', 'wb-todo' );
				}

				echo esc_html( $due_date_str );
			}

			if ( 'todo_id' === $column_name ) {
				echo esc_html( $post_id );
			}
		}

		/**
		 * Actions performed for adding component for due date of todo list.
		 *
		 * @since    1.0.0
		 * @access   public
		 * @author   Wbcom Designs
		 * @param    array $component_names contain default settings.
		 */
		public function bptodo_due_date_notifications_component( $component_names = array() ) {
			if ( ! is_array( $component_names ) ) {
				$component_names = array();
			}
			array_push( $component_names, 'bptodo_due_date' );
			return $component_names;
		}
		/**
		 * Function for check todo notification after every 6 hours.
		 *
		 * @param  mixed $schedules
		 * @return void
		 */
		public function bptodo_notification_cron_schedule( $schedules ) {
			$schedules['every_six_hours'] = array(
				'interval' => apply_filters( 'bptodo_notification_cron_schedule_interval', 21600 ), // Every 6 hours
				'display'  => __( 'Every 6 hours' ),
			);
			return $schedules;
		}

		/**
		 * Actions performed for formatting the notifications of bptodo due date.
		 *
		 * @since    1.0.0
		 * @access   public
		 * @author   Wbcom Designs
		 * @param    string $action contain todo action.
		 * @param    int    $item_id contain item id.
		 * @param    int    $secondary_item_id contain secondory id.
		 * @param    string $total_items total items.
		 * @param    string $format contain format.
		 */
		public function bptodo_format_due_date_notifications( $content, $item_id, $secondary_item_id, $total_items, $format = 'string', $component_action_name, $component_name, $id ) {
			global $bptodo;
			$profile_menu_label = $bptodo->profile_menu_label;
			if ( 'bptodo_due_date_action' === $component_action_name ) {
				$todo = get_post( $item_id );
				if ( ! empty( $todo ) ) {

					$todo_title = $todo->post_title;
					$todo_link  = get_permalink( $item_id );
					/* Translators: 1) Get a Plural Label Name 2) Display the To do title name*/
					$custom_title = sprintf( esc_html__( '%1$s due date arrived for task: %2$s', 'wb-todo' ), esc_html( $profile_menu_label ), esc_html( $todo_title ) );
					$custom_link  = $todo_link;
					/* Translators: 1) Get a Plural Label Name 2) Display the To do title name*/
					$custom_text = sprintf( esc_html__( 'Your %1$s: %2$s is due today. Please complete it as soon as possible.', 'wb-todo' ), esc_html( $profile_menu_label ), esc_html( $todo_title ) );

					/** WP Toolbar. */
					if ( 'string' === $format ) {
						$action = '<a href="' . esc_url( $custom_link ) . '" title="' . esc_attr( $custom_title ) . '">' . esc_html( $custom_text ) . '</a>';
					} else {
						/** Deprecated BuddyBar. */
						$action = array(
							'text' => $custom_text,
							'link' => $custom_link,
						);
					}
				}
			}
			return $action;
		}

		/**
		 * Register the shortcode - bptodo_by_categpry that will list all the todo items according to the category.
		 *
		 * @since    1.0.0
		 * @access   public
		 * @author   Wbcom Designs
		 * @param    string $atts contain attribute.
		 */
		public function bptodo_by_categpry_template( $atts ) {
			if ( is_user_logged_in() ) {
				ob_start();
				$shortcode_template = BPTODO_PLUGIN_PATH . 'inc/todo/bptodo-by-category-template.php';
				if ( file_exists( $shortcode_template ) ) {
					include_once $shortcode_template;
				}
				return ob_get_clean();
			} else {
				$shortcode_template_loggedout_user = BPTODO_PLUGIN_PATH . 'inc/todo/bptodo-by-category-template-loggedout-user.php';
				if ( file_exists( $shortcode_template_loggedout_user ) ) {
					include_once $shortcode_template_loggedout_user;
				}
			}
		}
	}
	new Bptodo_Hooks();
}
